/*
 * English words for generation of easy to memorize random passphrases.
 * This list comes from the MakePass passphrase generator developed by
 * Dianelos Georgoudis <dianelos at tecapro.com>, which was announced on
 * sci.crypt on 1997/10/24.  Here's a relevant excerpt from that posting:
 *
 * > The 4096 words in the word list were chosen according to the following
 * > criteria:
 * >    - each word must contain between 3 and 6 characters
 * >    - each word must be a common English word
 * >    - each word should be clearly different from each other
 * >      word, orthographically or semantically
 * >
 * > The MakePass word list has been placed in the public domain
 *
 * At least two other sci.crypt postings by Dianelos Georgoudis also state
 * that the word list is in the public domain, and so did the web page at:
 *
 * https://web.archive.org/web/%2a/http://www.tecapro.com/makepass.html
 *
 * which existed until 2006 and is available from the Wayback Machine as of
 * this writing (March 2010).  Specifically, the web page said:
 *
 * > The MakePass word list has been placed in the public domain.  To download
 * > a copy click here.  You can use the MakePass word list for many other
 * > purposes.
 *
 * "To download a copy click here" was a link to free/makepass.lst, which is
 * currently available via the Wayback Machine:
 *
 * https://web.archive.org/web/%2a/http://www.tecapro.com/free/makepass.lst
 *
 * Further lists of common English words were appended to the end to allow for
 * subsequent removal of "inappropriate" words from the initial list.
 *
 * Even though the original description of the list stated that "each word
 * must contain between 3 and 6 characters", there were two 7-character words.
 * These have been removed.
 *
 * Many "inappropriate" words have then been moved to near the end of list, so
 * that they're not used for generated passphrases.
 *
 * The code in passwdqc_check.c and passwdqc_random.c makes the following
 * assumptions about this list:
 *
 * - the first 4096 words are for random passphrase generation, and there are
 * at least this many words present;
 * - the words are of up to 6 characters long;
 * - although some words may contain capital letters, no two words differ by
 * the case of characters alone (e.g., converting the list to all-lowercase
 * would yield a list of as many unique words);
 * - the words contain alphabetical characters only;
 * - if an entire word on this list matches the initial substring of other
 * word(s) on the list, it is likely placed immediately before those words
 * (e.g., "bake", "baker", "bakery"), which speeds up the "word-based" check.
 *
 * Additionally, the default minimum passphrase length of 11 characters
 * specified in passwdqc_parse.c has been chosen such that a passphrase
 * consisting of any three words from this list with two separator
 * characters will pass the minimum length check.  In other words, this
 * default assumes that no word is shorter than 3 characters.
 */

#include "wordset_4k.h"

const char _passwdqc_wordset_4k[][WORDSET_4K_LENGTH_MAX] = {
	"Adam",
	"Alaska",
	"Alice",
	"Amazon",
	"Andrew",
	"Angola",
	"Antony",
	"April",
	"Arctic",
	"Athens",
	"Austin",
	"Baltic",
	"Berlin",
	"Bombay",
	"Bonn",
	"Boston",
	"Brazil",
	"Burma",
	"Cairo",
	"Canada",
	"Carl",
	"Carol",
	"Chile",
	"China",
	"Congo",
	"Cuba",
	"Cyprus",
	"Czech",
	"Dallas",
	"David",
	"Delhi",
	"Derby",
	"Diana",
	"Dublin",
	"East",
	"Eden",
	"Edward",
	"Eric",
	"Essex",
	"Europe",
	"Eve",
	"France",
	"Friday",
	"Gemini",
	"Geneva",
	"George",
	"Gloria",
	"Gothic",
	"Greece",
	"Hague",
	"Haiti",
	"Hanoi",
	"Harry",
	"Havana",
	"Hawaii",
	"Henry",
	"Hermes",
	"Idaho",
	"Inca",
	"India",
	"Iowa",
	"Iran",
	"Iraq",
	"Isaac",
	"Isabel",
	"Israel",
	"Italy",
	"Ivan",
	"Jack",
	"Jacob",
	"James",
	"Japan",
	"Java",
	"Jersey",
	"Jim",
	"John",
	"Jordan",
	"Joseph",
	"Judy",
	"July",
	"June",
	"Kansas",
	"Karl",
	"Kenya",
	"Korea",
	"Kuwait",
	"Laos",
	"Latin",
	"Leo",
	"Libya",
	"Lima",
	"Lisbon",
	"Liz",
	"London",
	"Louvre",
	"Lucy",
	"Luther",
	"Madrid",
	"Malta",
	"Maria",
	"Mars",
	"Mary",
	"Maya",
	"Mecca",
	"Mexico",
	"Miami",
	"Mickey",
	"Milan",
	"Monaco",
	"Monday",
	"Moscow",
	"Munich",
	"Naples",
	"Nepal",
	"Newark",
	"Nile",
	"North",
	"Norway",
	"Ohio",
	"Oscar",
	"Oslo",
	"Oxford",
	"Panama",
	"Paris",
	"Paul",
	"Peking",
	"Peru",
	"Peter",
	"Philip",
	"Poland",
	"Prague",
	"Quebec",
	"Rex",
	"Rhine",
	"Robert",
	"Roman",
	"Rome",
	"Rosa",
	"Russia",
	"Sahara",
	"Sam",
	"Saturn",
	"Seoul",
	"Somali",
	"Spain",
	"Sudan",
	"Suez",
	"Sunday",
	"Sweden",
	"Sydney",
	"Syria",
	"Taiwan",
	"Tarzan",
	"Taurus",
	"Tehran",
	"Teresa",
	"Texas",
	"Thomas",
	"Tibet",
	"Tokyo",
	"Tom",
	"Turkey",
	"Uganda",
	"Venice",
	"Venus",
	"Vienna",
	"Viking",
	"Virgo",
	"Warsaw",
	"West",
	"Yale",
	"Yemen",
	"York",
	"Zaire",
	"Zurich",
	"aback",
	"abbey",
	"abbot",
	"abide",
	"ablaze",
	"able",
	"aboard",
	"abode",
	"abound",
	"about",
	"above",
	"abroad",
	"abrupt",
	"absent",
	"absorb",
	"absurd",
	"abuse",
	"accent",
	"accept",
	"access",
	"accord",
	"accuse",
	"ace",
	"ache",
	"aching",
	"acid",
	"acidic",
	"acorn",
	"acre",
	"across",
	"act",
	"action",
	"active",
	"actor",
	"actual",
	"acute",
	"adapt",
	"add",
	"added",
	"addict",
	"adept",
	"adhere",
	"adjust",
	"admire",
	"admit",
	"adobe",
	"adopt",
	"adrift",
	"adult",
	"adverb",
	"advert",
	"aerial",
	"afar",
	"affair",
	"affect",
	"afford",
	"afield",
	"afloat",
	"afraid",
	"afresh",
	"after",
	"again",
	"age",
	"agency",
	"agenda",
	"agent",
	"aghast",
	"agile",
	"ago",
	"agony",
	"agree",
	"agreed",
	"ahead",
	"aid",
	"aide",
	"aim",
	"air",
	"airman",
	"airy",
	"akin",
	"alarm",
	"albeit",
	"album",
	"alert",
	"alibi",
	"alien",
	"alight",
	"align",
	"alike",
	"alive",
	"alkali",
	"all",
	"alley",
	"allied",
	"allow",
	"alloy",
	"ally",
	"almond",
	"almost",
	"aloft",
	"alone",
	"along",
	"aloof",
	"aloud",
	"alpha",
	"alpine",
	"also",
	"altar",
	"alter",
	"always",
	"amaze",
	"amber",
	"ambush",
	"amen",
	"amend",
	"amid",
	"amidst",
	"amiss",
	"among",
	"amount",
	"ample",
	"amuse",
	"anchor",
	"and",
	"anew",
	"angel",
	"anger",
	"angle",
	"angry",
	"animal",
	"ankle",
	"annoy",
	"annual",
	"answer",
	"anthem",
	"anti",
	"any",
	"anyhow",
	"anyway",
	"apart",
	"apathy",
	"apex",
	"apiece",
	"appeal",
	"appear",
	"apple",
	"apply",
	"apron",
	"arcade",
	"arcane",
	"arch",
	"ardent",
	"are",
	"area",
	"argue",
	"arid",
	"arise",
	"arm",
	"armful",
	"armpit",
	"army",
	"aroma",
	"around",
	"array",
	"arrest",
	"arrive",
	"arrow",
	"arson",
	"art",
	"artery",
	"artful",
	"artist",
	"ascent",
	"ashen",
	"ashore",
	"aside",
	"ask",
	"asleep",
	"aspect",
	"assay",
	"assent",
	"assert",
	"assess",
	"asset",
	"assign",
	"assist",
	"assume",
	"assure",
	"asthma",
	"astute",
	"asylum",
	"ate",
	"atlas",
	"atom",
	"atomic",
	"attach",
	"attack",
	"attain",
	"attend",
	"attic",
	"auburn",
	"audio",
	"audit",
	"august",
	"aunt",
	"auntie",
	"aura",
	"author",
	"auto",
	"autumn",
	"avail",
	"avenge",
	"avenue",
	"avert",
	"avid",
	"avoid",
	"await",
	"awake",
	"awaken",
	"award",
	"aware",
	"awash",
	"away",
	"awful",
	"awhile",
	"axes",
	"axiom",
	"axis",
	"axle",
	"aye",
	"baby",
	"back",
	"backup",
	"bacon",
	"bad",
	"badge",
	"badly",
	"bag",
	"baggy",
	"bail",
	"bait",
	"bake",
	"baker",
	"bakery",
	"bald",
	"ball",
	"ballad",
	"ballet",
	"ballot",
	"bamboo",
	"ban",
	"banal",
	"banana",
	"band",
	"bank",
	"bar",
	"barber",
	"bare",
	"barely",
	"barge",
	"bark",
	"barley",
	"barn",
	"baron",
	"barrel",
	"barren",
	"basalt",
	"base",
	"basic",
	"basil",
	"basin",
	"basis",
	"basket",
	"bass",
	"bat",
	"batch",
	"bath",
	"baton",
	"battle",
	"bay",
	"beach",
	"beacon",
	"beak",
	"beam",
	"bean",
	"bear",
	"beard",
	"beast",
	"beat",
	"beauty",
	"become",
	"bed",
	"beech",
	"beef",
	"beefy",
	"beep",
	"beer",
	"beet",
	"beetle",
	"before",
	"beggar",
	"begin",
	"behalf",
	"behave",
	"behind",
	"beige",
	"being",
	"belief",
	"bell",
	"belly",
	"belong",
	"below",
	"belt",
	"bench",
	"bend",
	"benign",
	"bent",
	"berry",
	"berth",
	"beset",
	"beside",
	"best",
	"bestow",
	"bet",
	"beta",
	"betray",
	"better",
	"beware",
	"beyond",
	"bias",
	"biceps",
	"bicker",
	"bid",
	"big",
	"bigger",
	"bike",
	"bile",
	"bill",
	"binary",
	"bind",
	"biopsy",
	"birch",
	"bird",
	"birdie",
	"birth",
	"bishop",
	"bit",
	"bite",
	"bitter",
	"blade",
	"blame",
	"bland",
	"blast",
	"blaze",
	"bleak",
	"blend",
	"bless",
	"blind",
	"blink",
	"blip",
	"bliss",
	"blitz",
	"block",
	"blond",
	"blood",
	"bloody",
	"bloom",
	"blot",
	"blouse",
	"blue",
	"bluff",
	"blunt",
	"blur",
	"blush",
	"boar",
	"board",
	"boast",
	"boat",
	"bodily",
	"body",
	"bogus",
	"boil",
	"bold",
	"bolt",
	"bomb",
	"bond",
	"bone",
	"bonnet",
	"bonus",
	"bony",
	"book",
	"boom",
	"boost",
	"boot",
	"booth",
	"border",
	"bore",
	"borrow",
	"bosom",
	"boss",
	"both",
	"bother",
	"bottle",
	"bottom",
	"bought",
	"bounce",
	"bound",
	"bounty",
	"bout",
	"bovine",
	"bow",
	"bowel",
	"bowl",
	"box",
	"boy",
	"boyish",
	"brace",
	"brain",
	"brainy",
	"brake",
	"bran",
	"branch",
	"brand",
	"brandy",
	"brass",
	"brave",
	"bravo",
	"breach",
	"bread",
	"break",
	"breath",
	"bred",
	"breed",
	"breeze",
	"brew",
	"brick",
	"bride",
	"bridge",
	"brief",
	"bright",
	"brim",
	"brine",
	"bring",
	"brink",
	"brisk",
	"broad",
	"broke",
	"broken",
	"bronze",
	"brook",
	"broom",
	"bruise",
	"brush",
	"brutal",
	"brute",
	"bubble",
	"buck",
	"bucket",
	"buckle",
	"budget",
	"buffet",
	"buggy",
	"build",
	"bulb",
	"bulge",
	"bulk",
	"bulky",
	"bull",
	"bullet",
	"bully",
	"bump",
	"bumpy",
	"bunch",
	"bundle",
	"bunk",
	"bunny",
	"burden",
	"bureau",
	"burial",
	"buried",
	"burly",
	"burn",
	"burrow",
	"burst",
	"bury",
	"bus",
	"bust",
	"bustle",
	"busy",
	"but",
	"butler",
	"butter",
	"button",
	"buy",
	"buyer",
	"buzz",
	"bye",
	"byte",
	"cab",
	"cabin",
	"cable",
	"cache",
	"cactus",
	"cage",
	"cake",
	"calf",
	"call",
	"caller",
	"calm",
	"calmly",
	"came",
	"camel",
	"camera",
	"camp",
	"campus",
	"can",
	"canal",
	"canary",
	"cancel",
	"cancer",
	"candid",
	"candle",
	"candy",
	"cane",
	"canine",
	"canoe",
	"canopy",
	"canvas",
	"canyon",
	"cap",
	"cape",
	"car",
	"carbon",
	"card",
	"care",
	"career",
	"caress",
	"cargo",
	"carp",
	"carpet",
	"carrot",
	"carry",
	"cart",
	"cartel",
	"case",
	"cash",
	"cask",
	"cast",
	"castle",
	"casual",
	"cat",
	"catch",
	"cater",
	"cattle",
	"caught",
	"causal",
	"cause",
	"cave",
	"cease",
	"celery",
	"cell",
	"cellar",
	"cement",
	"censor",
	"census",
	"cereal",
	"chain",
	"chair",
	"chalk",
	"chalky",
	"champ",
	"chance",
	"change",
	"chant",
	"chaos",
	"chap",
	"chapel",
	"charge",
	"charm",
	"chart",
	"chase",
	"chat",
	"cheap",
	"cheat",
	"check",
	"cheek",
	"cheeky",
	"cheer",
	"cheery",
	"cheese",
	"chef",
	"cherry",
	"chess",
	"chest",
	"chew",
	"chic",
	"chief",
	"child",
	"chill",
	"chilly",
	"chin",
	"chip",
	"choice",
	"choir",
	"choose",
	"chop",
	"choppy",
	"chord",
	"chorus",
	"chose",
	"chosen",
	"chrome",
	"chunk",
	"chunky",
	"cider",
	"cigar",
	"cinema",
	"circa",
	"circle",
	"circus",
	"cite",
	"city",
	"civic",
	"civil",
	"clad",
	"claim",
	"clammy",
	"clan",
	"clap",
	"clash",
	"clasp",
	"class",
	"clause",
	"claw",
	"clay",
	"clean",
	"clear",
	"clergy",
	"clerk",
	"clever",
	"click",
	"client",
	"cliff",
	"climb",
	"clinch",
	"cling",
	"clinic",
	"clip",
	"cloak",
	"clock",
	"clone",
	"close",
	"closer",
	"closet",
	"cloth",
	"cloud",
	"cloudy",
	"clout",
	"clown",
	"club",
	"clue",
	"clumsy",
	"clung",
	"clutch",
	"coach",
	"coal",
	"coarse",
	"coast",
	"coat",
	"coax",
	"cobalt",
	"cobra",
	"coca",
	"cocoa",
	"code",
	"coffee",
	"coffin",
	"cohort",
	"coil",
	"coin",
	"coke",
	"cold",
	"collar",
	"colon",
	"colony",
	"colt",
	"column",
	"comb",
	"combat",
	"come",
	"comedy",
	"comic",
	"commit",
	"common",
	"compel",
	"comply",
	"concur",
	"cone",
	"confer",
	"consul",
	"convex",
	"convey",
	"convoy",
	"cook",
	"cool",
	"cope",
	"copper",
	"copy",
	"coral",
	"cord",
	"core",
	"cork",
	"corn",
	"corner",
	"corps",
	"corpse",
	"corpus",
	"cortex",
	"cosmic",
	"cosmos",
	"cost",
	"costly",
	"cosy",
	"cotton",
	"couch",
	"cough",
	"could",
	"count",
	"county",
	"coup",
	"couple",
	"coupon",
	"course",
	"court",
	"cousin",
	"cove",
	"cover",
	"covert",
	"cow",
	"coward",
	"cowboy",
	"crab",
	"cradle",
	"craft",
	"crafty",
	"crag",
	"crane",
	"crap",
	"crash",
	"crate",
	"crater",
	"crawl",
	"crazy",
	"creak",
	"cream",
	"creamy",
	"create",
	"credit",
	"creed",
	"creek",
	"creep",
	"creepy",
	"crept",
	"crest",
	"crew",
	"cried",
	"crime",
	"crisis",
	"crisp",
	"critic",
	"croft",
	"crook",
	"crop",
	"cross",
	"crow",
	"crowd",
	"crown",
	"crude",
	"cruel",
	"cruise",
	"crunch",
	"crush",
	"crust",
	"crux",
	"cry",
	"crypt",
	"cube",
	"cubic",
	"cuckoo",
	"cuff",
	"cult",
	"cup",
	"curb",
	"cure",
	"curfew",
	"curl",
	"curry",
	"curse",
	"cursor",
	"curve",
	"custom",
	"cut",
	"cute",
	"cycle",
	"cyclic",
	"cynic",
	"dad",
	"dagger",
	"daily",
	"dairy",
	"daisy",
	"dale",
	"damage",
	"damn",
	"damp",
	"dampen",
	"dance",
	"danger",
	"dare",
	"dark",
	"darken",
	"dash",
	"data",
	"date",
	"dawn",
	"day",
	"dead",
	"deadly",
	"deaf",
	"deal",
	"dealer",
	"dean",
	"dear",
	"death",
	"debate",
	"debit",
	"debris",
	"debt",
	"debtor",
	"decade",
	"decay",
	"decent",
	"decide",
	"deck",
	"decor",
	"decree",
	"deduce",
	"deed",
	"deep",
	"deeply",
	"deer",
	"defeat",
	"defect",
	"defend",
	"defer",
	"define",
	"defy",
	"degree",
	"deity",
	"delay",
	"delete",
	"delta",
	"demand",
	"demise",
	"demo",
	"demon",
	"demure",
	"denial",
	"denote",
	"dense",
	"dental",
	"deny",
	"depart",
	"depend",
	"depict",
	"deploy",
	"depot",
	"depth",
	"deputy",
	"derive",
	"desert",
	"design",
	"desire",
	"desist",
	"desk",
	"detail",
	"detect",
	"deter",
	"detest",
	"detour",
	"device",
	"devise",
	"devoid",
	"devote",
	"devour",
	"dial",
	"diary",
	"dice",
	"dictum",
	"did",
	"die",
	"diesel",
	"diet",
	"differ",
	"digest",
	"digit",
	"dine",
	"dinghy",
	"dinner",
	"diode",
	"dire",
	"direct",
	"dirt",
	"dirty",
	"disc",
	"disco",
	"dish",
	"disk",
	"dismal",
	"dispel",
	"ditch",
	"dive",
	"divert",
	"divide",
	"divine",
	"dizzy",
	"docile",
	"dock",
	"doctor",
	"dog",
	"dogma",
	"dole",
	"doll",
	"dollar",
	"dolly",
	"domain",
	"dome",
	"domino",
	"donate",
	"done",
	"donkey",
	"donor",
	"doom",
	"door",
	"dorsal",
	"dose",
	"double",
	"doubt",
	"dough",
	"dour",
	"dove",
	"down",
	"dozen",
	"draft",
	"drag",
	"dragon",
	"drain",
	"drama",
	"drank",
	"draw",
	"drawer",
	"dread",
	"dream",
	"dreary",
	"dress",
	"drew",
	"dried",
	"drift",
	"drill",
	"drink",
	"drip",
	"drive",
	"driver",
	"drop",
	"drove",
	"drown",
	"drug",
	"drum",
	"drunk",
	"dry",
	"dual",
	"duck",
	"duct",
	"due",
	"duel",
	"duet",
	"duke",
	"dull",
	"duly",
	"dumb",
	"dummy",
	"dump",
	"dune",
	"dung",
	"duress",
	"during",
	"dusk",
	"dust",
	"dusty",
	"duty",
	"dwarf",
	"dwell",
	"dyer",
	"dying",
	"dynamo",
	"each",
	"eager",
	"eagle",
	"ear",
	"earl",
	"early",
	"earn",
	"earth",
	"ease",
	"easel",
	"easily",
	"easy",
	"eat",
	"eaten",
	"eater",
	"echo",
	"eddy",
	"edge",
	"edible",
	"edict",
	"edit",
	"editor",
	"eerie",
	"eerily",
	"effect",
	"effort",
	"egg",
	"ego",
	"eight",
	"eighth",
	"eighty",
	"either",
	"elbow",
	"elder",
	"eldest",
	"elect",
	"eleven",
	"elicit",
	"elite",
	"else",
	"elude",
	"elves",
	"embark",
	"emblem",
	"embryo",
	"emerge",
	"emit",
	"empire",
	"employ",
	"empty",
	"enable",
	"enamel",
	"end",
	"endure",
	"enemy",
	"energy",
	"engage",
	"engine",
	"enjoy",
	"enlist",
	"enough",
	"ensure",
	"entail",
	"enter",
	"entire",
	"entry",
	"envoy",
	"envy",
	"enzyme",
	"epic",
	"epoch",
	"equal",
	"equate",
	"equip",
	"equity",
	"era",
	"erode",
	"errant",
	"error",
	"escape",
	"essay",
	"estate",
	"esteem",
	"ethic",
	"ethnic",
	"evade",
	"even",
	"event",
	"ever",
	"every",
	"evict",
	"evil",
	"evoke",
	"evolve",
	"exact",
	"exam",
	"exceed",
	"excel",
	"except",
	"excess",
	"excise",
	"excite",
	"excuse",
	"exempt",
	"exert",
	"exile",
	"exist",
	"exit",
	"exotic",
	"expand",
	"expect",
	"expert",
	"expire",
	"export",
	"expose",
	"extend",
	"extra",
	"eye",
	"eyed",
	"fabric",
	"face",
	"fact",
	"factor",
	"fade",
	"fail",
	"faint",
	"fair",
	"fairly",
	"fairy",
	"faith",
	"fake",
	"falcon",
	"fall",
	"false",
	"falter",
	"fame",
	"family",
	"famine",
	"famous",
	"fan",
	"fancy",
	"far",
	"farce",
	"fare",
	"farm",
	"farmer",
	"fast",
	"fasten",
	"faster",
	"fat",
	"fatal",
	"fate",
	"father",
	"fatty",
	"fault",
	"faulty",
	"fauna",
	"fear",
	"feast",
	"feat",
	"fed",
	"fee",
	"feeble",
	"feed",
	"feel",
	"feet",
	"fell",
	"fellow",
	"felt",
	"female",
	"fence",
	"fend",
	"ferry",
	"fetal",
	"fetch",
	"feudal",
	"fever",
	"few",
	"fewer",
	"fiance",
	"fiasco",
	"fiddle",
	"field",
	"fiend",
	"fierce",
	"fiery",
	"fifth",
	"fifty",
	"fig",
	"fight",
	"figure",
	"file",
	"fill",
	"filled",
	"filler",
	"film",
	"filter",
	"filth",
	"filthy",
	"final",
	"finale",
	"find",
	"fine",
	"finger",
	"finish",
	"finite",
	"fire",
	"firm",
	"firmly",
	"first",
	"fiscal",
	"fish",
	"fisher",
	"fist",
	"fit",
	"fitful",
	"five",
	"fix",
	"flag",
	"flair",
	"flak",
	"flame",
	"flank",
	"flap",
	"flare",
	"flash",
	"flask",
	"flat",
	"flaw",
	"fled",
	"flee",
	"fleece",
	"fleet",
	"flesh",
	"fleshy",
	"flew",
	"flick",
	"flight",
	"flimsy",
	"flint",
	"float",
	"flock",
	"flood",
	"floor",
	"floppy",
	"flora",
	"floral",
	"flour",
	"flow",
	"flower",
	"fluent",
	"fluffy",
	"fluid",
	"flung",
	"flurry",
	"flush",
	"flute",
	"flux",
	"fly",
	"flyer",
	"foal",
	"foam",
	"focal",
	"focus",
	"fog",
	"foil",
	"fold",
	"folk",
	"follow",
	"folly",
	"fond",
	"fondly",
	"font",
	"food",
	"fool",
	"foot",
	"for",
	"forbid",
	"force",
	"ford",
	"forest",
	"forge",
	"forget",
	"fork",
	"form",
	"formal",
	"format",
	"former",
	"fort",
	"forth",
	"forty",
	"forum",
	"fossil",
	"foster",
	"foul",
	"found",
	"four",
	"fourth",
	"fox",
	"foyer",
	"frail",
	"frame",
	"franc",
	"frank",
	"fraud",
	"free",
	"freed",
	"freely",
	"freer",
	"freeze",
	"frenzy",
	"fresh",
	"friar",
	"fridge",
	"fried",
	"friend",
	"fright",
	"fringe",
	"frock",
	"frog",
	"from",
	"front",
	"frost",
	"frosty",
	"frown",
	"frozen",
	"frugal",
	"fruit",
	"fudge",
	"fuel",
	"fulfil",
	"full",
	"fully",
	"fun",
	"fund",
	"funny",
	"fur",
	"furry",
	"fury",
	"fuse",
	"fusion",
	"fuss",
	"fussy",
	"futile",
	"future",
	"fuzzy",
	"gadget",
	"gain",
	"gala",
	"galaxy",
	"gale",
	"gall",
	"galley",
	"gallon",
	"gallop",
	"gamble",
	"game",
	"gamma",
	"gang",
	"gap",
	"garage",
	"garden",
	"garlic",
	"gas",
	"gasp",
	"gate",
	"gather",
	"gauge",
	"gaunt",
	"gave",
	"gaze",
	"gear",
	"geese",
	"gender",
	"gene",
	"genial",
	"genius",
	"genre",
	"gentle",
	"gently",
	"gentry",
	"genus",
	"get",
	"ghetto",
	"ghost",
	"giant",
	"gift",
	"giggle",
	"gill",
	"gilt",
	"ginger",
	"girl",
	"give",
	"given",
	"glad",
	"glade",
	"glance",
	"gland",
	"glare",
	"glass",
	"glassy",
	"gleam",
	"glee",
	"glide",
	"global",
	"globe",
	"gloom",
	"gloomy",
	"glory",
	"gloss",
	"glossy",
	"glove",
	"glow",
	"glue",
	"goal",
	"goat",
	"gold",
	"golden",
	"golf",
	"gone",
	"gong",
	"good",
	"goose",
	"gorge",
	"gory",
	"gosh",
	"gossip",
	"got",
	"govern",
	"gown",
	"grab",
	"grace",
	"grade",
	"grain",
	"grand",
	"grant",
	"grape",
	"graph",
	"grasp",
	"grass",
	"grassy",
	"grate",
	"grave",
	"gravel",
	"gravy",
	"grease",
	"greasy",
	"great",
	"greed",
	"greedy",
	"green",
	"greet",
	"grew",
	"grid",
	"grief",
	"grill",
	"grim",
	"grin",
	"grind",
	"grip",
	"grit",
	"gritty",
	"groan",
	"groin",
	"groom",
	"groove",
	"gross",
	"ground",
	"group",
	"grove",
	"grow",
	"grown",
	"growth",
	"grudge",
	"grunt",
	"guard",
	"guess",
	"guest",
	"guide",
	"guild",
	"guilt",
	"guilty",
	"guise",
	"guitar",
	"gulf",
	"gully",
	"gun",
	"gunman",
	"guru",
	"gut",
	"guy",
	"habit",
	"hack",
	"had",
	"hail",
	"hair",
	"hairy",
	"hale",
	"half",
	"hall",
	"halt",
	"hamlet",
	"hammer",
	"hand",
	"handle",
	"handy",
	"hang",
	"hangar",
	"happen",
	"happy",
	"harass",
	"hard",
	"harder",
	"hardly",
	"hare",
	"harem",
	"harm",
	"harp",
	"harsh",
	"has",
	"hash",
	"hassle",
	"haste",
	"hasten",
	"hasty",
	"hat",
	"hatch",
	"hate",
	"haul",
	"haunt",
	"have",
	"haven",
	"havoc",
	"hawk",
	"hazard",
	"haze",
	"hazel",
	"hazy",
	"head",
	"heal",
	"health",
	"heap",
	"hear",
	"heard",
	"heart",
	"hearth",
	"hearty",
	"heat",
	"heater",
	"heaven",
	"heavy",
	"heck",
	"hectic",
	"hedge",
	"heel",
	"hefty",
	"height",
	"heir",
	"held",
	"helium",
	"helix",
	"hell",
	"hello",
	"helm",
	"helmet",
	"help",
	"hemp",
	"hence",
	"her",
	"herald",
	"herb",
	"herd",
	"here",
	"hereby",
	"hernia",
	"hero",
	"heroic",
	"hey",
	"heyday",
	"hick",
	"hidden",
	"hide",
	"high",
	"higher",
	"highly",
	"hill",
	"him",
	"hind",
	"hint",
	"hire",
	"his",
	"hiss",
	"hit",
	"hive",
	"hoard",
	"hoarse",
	"hobby",
	"hockey",
	"hold",
	"holder",
	"hole",
	"hollow",
	"holly",
	"holy",
	"home",
	"honest",
	"honey",
	"hood",
	"hook",
	"hope",
	"horn",
	"horrid",
	"horror",
	"horse",
	"hose",
	"host",
	"hot",
	"hotel",
	"hound",
	"hour",
	"house",
	"hover",
	"how",
	"huge",
	"hull",
	"human",
	"humane",
	"humble",
	"humid",
	"hung",
	"hunger",
	"hungry",
	"hunt",
	"hurdle",
	"hurl",
	"hurry",
	"hurt",
	"hush",
	"hut",
	"hybrid",
	"hymn",
	"hyphen",
	"ice",
	"icing",
	"icon",
	"idea",
	"ideal",
	"idiom",
	"idiot",
	"idle",
	"idly",
	"idol",
	"ignite",
	"ignore",
	"ill",
	"image",
	"immune",
	"impact",
	"imply",
	"import",
	"impose",
	"inch",
	"income",
	"incur",
	"indeed",
	"index",
	"indoor",
	"induce",
	"inept",
	"inert",
	"infant",
	"infect",
	"infer",
	"influx",
	"inform",
	"inject",
	"injure",
	"injury",
	"inlaid",
	"inland",
	"inlet",
	"inmate",
	"inn",
	"innate",
	"inner",
	"input",
	"insane",
	"insect",
	"insert",
	"inset",
	"inside",
	"insist",
	"insult",
	"insure",
	"intact",
	"intake",
	"intend",
	"inter",
	"into",
	"invade",
	"invent",
	"invest",
	"invite",
	"invoke",
	"inward",
	"iron",
	"ironic",
	"irony",
	"island",
	"isle",
	"issue",
	"itch",
	"item",
	"itself",
	"ivory",
	"jacket",
	"jade",
	"jaguar",
	"jail",
	"jargon",
	"jaw",
	"jazz",
	"jeep",
	"jelly",
	"jerky",
	"jest",
	"jet",
	"jewel",
	"job",
	"jock",
	"jockey",
	"join",
	"joke",
	"jolly",
	"jolt",
	"joy",
	"joyful",
	"joyous",
	"judge",
	"juice",
	"juicy",
	"jumble",
	"jumbo",
	"jump",
	"jungle",
	"junior",
	"junk",
	"junta",
	"jury",
	"just",
	"karate",
	"keel",
	"keen",
	"keep",
	"keeper",
	"kept",
	"kernel",
	"kettle",
	"key",
	"khaki",
	"kick",
	"kid",
	"kidnap",
	"kidney",
	"kin",
	"kind",
	"kindly",
	"king",
	"kiss",
	"kite",
	"kitten",
	"knack",
	"knee",
	"knew",
	"knife",
	"knight",
	"knit",
	"knob",
	"knock",
	"knot",
	"know",
	"known",
	"label",
	"lace",
	"lack",
	"lad",
	"ladder",
	"laden",
	"lady",
	"lagoon",
	"laity",
	"lake",
	"lamb",
	"lame",
	"lamp",
	"lance",
	"land",
	"lane",
	"lap",
	"lapse",
	"large",
	"larval",
	"laser",
	"last",
	"latch",
	"late",
	"lately",
	"latent",
	"later",
	"latest",
	"latter",
	"laugh",
	"launch",
	"lava",
	"lavish",
	"law",
	"lawful",
	"lawn",
	"lawyer",
	"lay",
	"layer",
	"layman",
	"lazy",
	"lead",
	"leader",
	"leaf",
	"leafy",
	"league",
	"leak",
	"leaky",
	"lean",
	"leap",
	"learn",
	"lease",
	"leash",
	"least",
	"leave",
	"led",
	"ledge",
	"left",
	"leg",
	"legacy",
	"legal",
	"legend",
	"legion",
	"lemon",
	"lend",
	"length",
	"lens",
	"lent",
	"leper",
	"lesion",
	"less",
	"lessen",
	"lesser",
	"lesson",
	"lest",
	"let",
	"lethal",
	"letter",
	"level",
	"lever",
	"levy",
	"lewis",
	"liable",
	"liar",
	"libel",
	"lice",
	"lid",
	"lie",
	"lied",
	"life",
	"lift",
	"light",
	"like",
	"likely",
	"limb",
	"lime",
	"limit",
	"limp",
	"line",
	"linear",
	"linen",
	"linger",
	"link",
	"lion",
	"lip",
	"liquid",
	"liquor",
	"list",
	"listen",
	"lit",
	"live",
	"lively",
	"liver",
	"lizard",
	"load",
	"loaf",
	"loan",
	"lobby",
	"lobe",
	"local",
	"locate",
	"lock",
	"locus",
	"lodge",
	"loft",
	"lofty",
	"log",
	"logic",
	"logo",
	"lone",
	"lonely",
	"long",
	"longer",
	"look",
	"loop",
	"loose",
	"loosen",
	"loot",
	"lord",
	"lorry",
	"lose",
	"loss",
	"lost",
	"lot",
	"lotion",
	"lotus",
	"loud",
	"loudly",
	"lounge",
	"lousy",
	"love",
	"lovely",
	"low",
	"lower",
	"lowest",
	"loyal",
	"lucid",
	"luck",
	"lucky",
	"lull",
	"lump",
	"lumpy",
	"lunacy",
	"lunar",
	"lunch",
	"lung",
	"lure",
	"lurid",
	"lush",
	"lust",
	"lute",
	"luxury",
	"lying",
	"lymph",
	"lynch",
	"lyric",
	"macho",
	"macro",
	"mad",
	"madam",
	"made",
	"mafia",
	"magic",
	"magma",
	"magnet",
	"magnum",
	"maid",
	"maiden",
	"mail",
	"main",
	"mainly",
	"major",
	"make",
	"maker",
	"male",
	"malice",
	"mall",
	"malt",
	"mammal",
	"manage",
	"mane",
	"mania",
	"manic",
	"manner",
	"manor",
	"mantle",
	"manual",
	"manure",
	"many",
	"map",
	"maple",
	"marble",
	"march",
	"mare",
	"margin",
	"marina",
	"mark",
	"market",
	"marry",
	"marsh",
	"martin",
	"martyr",
	"mask",
	"mason",
	"mass",
	"mast",
	"match",
	"mate",
	"matrix",
	"matter",
	"mature",
	"maxim",
	"may",
	"maybe",
	"mayor",
	"maze",
	"mead",
	"meadow",
	"meal",
	"mean",
	"meant",
	"meat",
	"medal",
	"media",
	"median",
	"medic",
	"medium",
	"meet",
	"mellow",
	"melody",
	"melon",
	"melt",
	"member",
	"memo",
	"memory",
	"menace",
	"mend",
	"mental",
	"mentor",
	"menu",
	"mercy",
	"mere",
	"merely",
	"merge",
	"merger",
	"merit",
	"merry",
	"mesh",
	"mess",
	"messy",
	"met",
	"metal",
	"meter",
	"method",
	"methyl",
	"metric",
	"metro",
	"mid",
	"midday",
	"middle",
	"midst",
	"midway",
	"might",
	"mighty",
	"mild",
	"mildew",
	"mile",
	"milk",
	"milky",
	"mill",
	"mimic",
	"mince",
	"mind",
	"mine",
	"mini",
	"mink",
	"minor",
	"mint",
	"minus",
	"minute",
	"mirror",
	"mirth",
	"misery",
	"miss",
	"mist",
	"misty",
	"mite",
	"mix",
	"moan",
	"moat",
	"mobile",
	"mock",
	"mode",
	"model",
	"modem",
	"modern",
	"modest",
	"modify",
	"module",
	"moist",
	"molar",
	"mole",
	"molten",
	"moment",
	"money",
	"monies",
	"monk",
	"monkey",
	"month",
	"mood",
	"moody",
	"moon",
	"moor",
	"moral",
	"morale",
	"morbid",
	"more",
	"morgue",
	"mortal",
	"mortar",
	"mosaic",
	"mosque",
	"moss",
	"most",
	"mostly",
	"moth",
	"mother",
	"motion",
	"motive",
	"motor",
	"mould",
	"mount",
	"mourn",
	"mouse",
	"mouth",
	"move",
	"movie",
	"much",
	"muck",
	"mucus",
	"mud",
	"muddle",
	"muddy",
	"mule",
	"mummy",
	"murky",
	"murmur",
	"muscle",
	"museum",
	"music",
	"mussel",
	"must",
	"mutant",
	"mute",
	"mutiny",
	"mutter",
	"mutton",
	"mutual",
	"muzzle",
	"myopic",
	"myriad",
	"myself",
	"mystic",
	"myth",
	"nadir",
	"nail",
	"name",
	"namely",
	"nape",
	"napkin",
	"narrow",
	"nasal",
	"nasty",
	"nation",
	"native",
	"nature",
	"nausea",
	"naval",
	"nave",
	"navy",
	"near",
	"nearer",
	"nearly",
	"neat",
	"neatly",
	"neck",
	"need",
	"needle",
	"needy",
	"negate",
	"neon",
	"nephew",
	"nerve",
	"nest",
	"neural",
	"never",
	"newly",
	"next",
	"nice",
	"nicely",
	"niche",
	"nickel",
	"niece",
	"night",
	"nimble",
	"nine",
	"ninety",
	"ninth",
	"noble",
	"nobody",
	"node",
	"noise",
	"noisy",
	"non",
	"none",
	"noon",
	"nor",
	"norm",
	"normal",
	"nose",
	"nosy",
	"not",
	"note",
	"notice",
	"notify",
	"notion",
	"nought",
	"noun",
	"novel",
	"novice",
	"now",
	"nozzle",
	"null",
	"numb",
	"number",
	"nurse",
	"nylon",
	"nymph",
	"oak",
	"oasis",
	"oath",
	"obese",
	"obey",
	"object",
	"oblige",
	"oboe",
	"obtain",
	"occult",
	"occupy",
	"occur",
	"ocean",
	"octave",
	"odd",
	"off",
	"offend",
	"offer",
	"office",
	"offset",
	"often",
	"oil",
	"oily",
	"okay",
	"old",
	"older",
	"oldest",
	"olive",
	"omega",
	"omen",
	"omit",
	"once",
	"one",
	"onion",
	"only",
	"onset",
	"onto",
	"onus",
	"onward",
	"opaque",
	"open",
	"openly",
	"opera",
	"oppose",
	"optic",
	"option",
	"oracle",
	"orange",
	"orbit",
	"orchid",
	"ordeal",
	"order",
	"organ",
	"orient",
	"origin",
	"ornate",
	"orphan",
	"other",
	"otter",
	"ought",
	"ounce",
	"our",
	"out",
	"outer",
	"output",
	"outset",
	"oval",
	"oven",
	"over",
	"overt",
	"owe",
	"owing",
	"owl",
	"own",
	"owner",
	"oxide",
	"oxygen",
	"oyster",
	"ozone",
	"pace",
	"pack",
	"packet",
	"pact",
	"paddle",
	"paddy",
	"pagan",
	"page",
	"paid",
	"pain",
	"paint",
	"pair",
	"palace",
	"pale",
	"palm",
	"panel",
	"panic",
	"papa",
	"papal",
	"paper",
	"parade",
	"parcel",
	"pardon",
	"parent",
	"parish",
	"park",
	"parody",
	"parrot",
	"part",
	"partly",
	"party",
	"pass",
	"past",
	"paste",
	"pastel",
	"pastor",
	"pastry",
	"pat",
	"patch",
	"patent",
	"path",
	"patio",
	"patrol",
	"patron",
	"pause",
	"pave",
	"pawn",
	"pay",
	"peace",
	"peach",
	"peak",
	"pear",
	"pearl",
	"pedal",
	"peel",
	"peer",
	"pelvic",
	"pelvis",
	"pen",
	"penal",
	"pence",
	"pencil",
	"penny",
	"people",
	"pepper",
	"per",
	"perch",
	"peril",
	"period",
	"perish",
	"permit",
	"person",
	"pest",
	"petite",
	"petrol",
	"petty",
	"phase",
	"phone",
	"photo",
	"phrase",
	"piano",
	"pick",
	"picket",
	"picnic",
	"pie",
	"piece",
	"pier",
	"pierce",
	"piety",
	"pig",
	"pigeon",
	"piggy",
	"pike",
	"pile",
	"pill",
	"pillar",
	"pillow",
	"pilot",
	"pin",
	"pinch",
	"pine",
	"pink",
	"pint",
	"pious",
	"pipe",
	"pirate",
	"pistol",
	"piston",
	"pit",
	"pitch",
	"pity",
	"pivot",
	"pixel",
	"pizza",
	"place",
	"placid",
	"plague",
	"plain",
	"plan",
	"plane",
	"planet",
	"plank",
	"plant",
	"plasma",
	"plate",
	"play",
	"player",
	"plea",
	"plead",
	"please",
	"pledge",
	"plenty",
	"plenum",
	"plight",
	"plot",
	"ploy",
	"plug",
	"plum",
	"plump",
	"plunge",
	"plural",
	"plus",
	"plush",
	"pocket",
	"poem",
	"poet",
	"poetic",
	"poetry",
	"point",
	"poison",
	"polar",
	"pole",
	"police",
	"policy",
	"polite",
	"poll",
	"pollen",
	"polo",
	"pond",
	"ponder",
	"pony",
	"pool",
	"poor",
	"poorly",
	"pop",
	"pope",
	"poppy",
	"pore",
	"pork",
	"port",
	"portal",
	"pose",
	"posh",
	"post",
	"postal",
	"potato",
	"potent",
	"pouch",
	"pound",
	"pour",
	"powder",
	"power",
	"praise",
	"pray",
	"prayer",
	"preach",
	"prefer",
	"prefix",
	"press",
	"pretty",
	"price",
	"pride",
	"priest",
	"primal",
	"prime",
	"prince",
	"print",
	"prior",
	"prism",
	"prison",
	"privy",
	"prize",
	"probe",
	"profit",
	"prompt",
	"prone",
	"proof",
	"propel",
	"proper",
	"prose",
	"proton",
	"proud",
	"prove",
	"proven",
	"proxy",
	"prune",
	"psalm",
	"pseudo",
	"psyche",
	"pub",
	"public",
	"puff",
	"pull",
	"pulp",
	"pulpit",
	"pulsar",
	"pulse",
	"pump",
	"punch",
	"punish",
	"punk",
	"pupil",
	"puppet",
	"puppy",
	"pure",
	"purely",
	"purge",
	"purify",
	"purple",
	"purse",
	"pursue",
	"push",
	"pushy",
	"put",
	"putt",
	"puzzle",
	"quaint",
	"quake",
	"quarry",
	"quartz",
	"quay",
	"queen",
	"query",
	"quest",
	"queue",
	"quick",
	"quid",
	"quiet",
	"quilt",
	"quirk",
	"quit",
	"quite",
	"quiver",
	"quiz",
	"quota",
	"quote",
	"rabbit",
	"race",
	"racial",
	"racism",
	"rack",
	"racket",
	"radar",
	"radio",
	"radish",
	"radius",
	"raffle",
	"raft",
	"rage",
	"raid",
	"rail",
	"rain",
	"rainy",
	"raise",
	"rally",
	"ramp",
	"random",
	"range",
	"rank",
	"ransom",
	"rapid",
	"rare",
	"rarely",
	"rarity",
	"rash",
	"rat",
	"rate",
	"rather",
	"ratify",
	"ratio",
	"rattle",
	"rave",
	"raven",
	"raw",
	"ray",
	"razor",
	"reach",
	"react",
	"read",
	"reader",
	"ready",
	"real",
	"really",
	"realm",
	"reap",
	"rear",
	"reason",
	"rebel",
	"recall",
	"recent",
	"recess",
	"recipe",
	"reckon",
	"record",
	"recoup",
	"rector",
	"red",
	"redeem",
	"reduce",
	"reed",
	"reef",
	"refer",
	"reform",
	"refuge",
	"refuse",
	"regal",
	"regard",
	"regent",
	"regime",
	"region",
	"regret",
	"reign",
	"reject",
	"relate",
	"relax",
	"relay",
	"relic",
	"relief",
	"relish",
	"rely",
	"remain",
	"remark",
	"remedy",
	"remind",
	"remit",
	"remote",
	"remove",
	"renal",
	"render",
	"rent",
	"rental",
	"repair",
	"repeal",
	"repeat",
	"repent",
	"reply",
	"report",
	"rescue",
	"resent",
	"reside",
	"resign",
	"resin",
	"resist",
	"resort",
	"rest",
	"result",
	"resume",
	"retail",
	"retain",
	"retina",
	"retire",
	"return",
	"reveal",
	"review",
	"revise",
	"revive",
	"revolt",
	"reward",
	"rhino",
	"rhyme",
	"rhythm",
	"ribbon",
	"rice",
	"rich",
	"rick",
	"rid",
	"ride",
	"rider",
	"ridge",
	"rife",
	"rifle",
	"rift",
	"right",
	"rigid",
	"ring",
	"rinse",
	"riot",
	"ripe",
	"ripen",
	"ripple",
	"rise",
	"risk",
	"risky",
	"rite",
	"ritual",
	"rival",
	"river",
	"road",
	"roar",
	"roast",
	"rob",
	"robe",
	"robin",
	"robot",
	"robust",
	"rock",
	"rocket",
	"rocky",
	"rod",
	"rode",
	"rodent",
	"rogue",
	"role",
	"roll",
	"roof",
	"room",
	"root",
	"rope",
	"rose",
	"rosy",
	"rotate",
	"rotor",
	"rotten",
	"rouge",
	"rough",
	"round",
	"route",
	"rover",
	"row",
	"royal",
	"rubble",
	"ruby",
	"rudder",
	"rude",
	"rugby",
	"ruin",
	"rule",
	"ruler",
	"rumble",
	"rump",
	"run",
	"rune",
	"rung",
	"runway",
	"rural",
	"rush",
	"rust",
	"rustic",
	"rusty",
	"sack",
	"sacred",
	"sad",
	"saddle",
	"sadly",
	"safari",
	"safe",
	"safely",
	"safer",
	"safety",
	"saga",
	"sage",
	"said",
	"sail",
	"sailor",
	"saint",
	"sake",
	"salad",
	"salary",
	"sale",
	"saline",
	"saliva",
	"salmon",
	"saloon",
	"salt",
	"salty",
	"salute",
	"same",
	"sample",
	"sand",
	"sandy",
	"sane",
	"sash",
	"satin",
	"satire",
	"sauce",
	"sauna",
	"savage",
	"save",
	"say",
	"scale",
	"scalp",
	"scan",
	"scant",
	"scar",
	"scarce",
	"scare",
	"scarf",
	"scary",
	"scene",
	"scenic",
	"scent",
	"school",
	"scope",
	"score",
	"scorn",
	"scotch",
	"scout",
	"scrap",
	"scream",
	"screen",
	"script",
	"scroll",
	"scrub",
	"scum",
	"sea",
	"seal",
	"seam",
	"seaman",
	"search",
	"season",
	"seat",
	"second",
	"secret",
	"sect",
	"sector",
	"secure",
	"see",
	"seed",
	"seeing",
	"seek",
	"seem",
	"seize",
	"seldom",
	"select",
	"self",
	"sell",
	"seller",
	"semi",
	"senate",
	"send",
	"senile",
	"senior",
	"sense",
	"sensor",
	"sent",
	"sentry",
	"sequel",
	"serene",
	"serial",
	"series",
	"sermon",
	"serum",
	"serve",
	"server",
	"set",
	"settle",
	"seven",
	"severe",
	"sewage",
	"shabby",
	"shade",
	"shadow",
	"shady",
	"shaft",
	"shaggy",
	"shah",
	"shake",
	"shaky",
	"shall",
	"sham",
	"shame",
	"shape",
	"share",
	"shark",
	"sharp",
	"shawl",
	"she",
	"shear",
	"sheen",
	"sheep",
	"sheer",
	"sheet",
	"shelf",
	"shell",
	"sherry",
	"shield",
	"shift",
	"shine",
	"shiny",
	"ship",
	"shire",
	"shirt",
	"shiver",
	"shock",
	"shoe",
	"shook",
	"shoot",
	"shop",
	"shore",
	"short",
	"shot",
	"should",
	"shout",
	"show",
	"shower",
	"shrank",
	"shrewd",
	"shrill",
	"shrimp",
	"shrine",
	"shrink",
	"shrub",
	"shrug",
	"shut",
	"shy",
	"shyly",
	"sick",
	"side",
	"siege",
	"sigh",
	"sight",
	"sigma",
	"sign",
	"signal",
	"silent",
	"silk",
	"silken",
	"silky",
	"sill",
	"silly",
	"silver",
	"simple",
	"simply",
	"since",
	"sinful",
	"sing",
	"singer",
	"single",
	"sink",
	"sir",
	"siren",
	"sister",
	"sit",
	"site",
	"six",
	"sixth",
	"sixty",
	"size",
	"sketch",
	"skill",
	"skin",
	"skinny",
	"skip",
	"skirt",
	"skull",
	"sky",
	"slab",
	"slack",
	"slain",
	"slam",
	"slang",
	"slap",
	"slate",
	"slater",
	"sleek",
	"sleep",
	"sleepy",
	"sleeve",
	"slice",
	"slick",
	"slid",
	"slide",
	"slight",
	"slim",
	"slimy",
	"sling",
	"slip",
	"slit",
	"slogan",
	"slope",
	"sloppy",
	"slot",
	"slow",
	"slowly",
	"slug",
	"slum",
	"slump",
	"smack",
	"small",
	"smart",
	"smash",
	"smear",
	"smell",
	"smelly",
	"smelt",
	"smile",
	"smoke",
	"smoky",
	"smooth",
	"smug",
	"snack",
	"snail",
	"snake",
	"snap",
	"snatch",
	"sneak",
	"snow",
	"snowy",
	"snug",
	"soak",
	"soap",
	"sober",
	"soccer",
	"social",
	"sock",
	"socket",
	"soda",
	"sodden",
	"sodium",
	"sofa",
	"soft",
	"soften",
	"softly",
	"soggy",
	"soil",
	"solar",
	"sold",
	"sole",
	"solely",
	"solemn",
	"solid",
	"solo",
	"solve",
	"some",
	"son",
	"sonar",
	"sonata",
	"song",
	"sonic",
	"soon",
	"sooner",
	"soot",
	"soothe",
	"sordid",
	"sore",
	"sorrow",
	"sorry",
	"sort",
	"soul",
	"sound",
	"soup",
	"sour",
	"source",
	"space",
	"spade",
	"span",
	"spare",
	"spark",
	"sparse",
	"spasm",
	"spat",
	"spate",
	"speak",
	"spear",
	"speech",
	"speed",
	"speedy",
	"spell",
	"spend",
	"sphere",
	"spice",
	"spicy",
	"spider",
	"spiky",
	"spill",
	"spin",
	"spinal",
	"spine",
	"spiral",
	"spirit",
	"spit",
	"spite",
	"splash",
	"split",
	"spoil",
	"spoke",
	"sponge",
	"spoon",
	"sport",
	"spot",
	"spouse",
	"spray",
	"spread",
	"spree",
	"spring",
	"sprint",
	"spur",
	"squad",
	"square",
	"squash",
	"squat",
	"squid",
	"stab",
	"stable",
	"stack",
	"staff",
	"stage",
	"stain",
	"stair",
	"stake",
	"stale",
	"stall",
	"stamp",
	"stance",
	"stand",
	"staple",
	"star",
	"starch",
	"stare",
	"stark",
	"start",
	"starve",
	"state",
	"static",
	"statue",
	"status",
	"stay",
	"stead",
	"steady",
	"steak",
	"steal",
	"steam",
	"steel",
	"steep",
	"steer",
	"stem",
	"stench",
	"step",
	"stereo",
	"stern",
	"stew",
	"stick",
	"sticky",
	"stiff",
	"stifle",
	"stigma",
	"still",
	"sting",
	"stint",
	"stir",
	"stitch",
	"stock",
	"stocky",
	"stone",
	"stony",
	"stool",
	"stop",
	"store",
	"storm",
	"stormy",
	"story",
	"stout",
	"stove",
	"strain",
	"strait",
	"strand",
	"strap",
	"strata",
	"straw",
	"stray",
	"streak",
	"stream",
	"street",
	"stress",
	"strict",
	"stride",
	"strife",
	"strike",
	"string",
	"strive",
	"stroke",
	"stroll",
	"strong",
	"stud",
	"studio",
	"study",
	"stuff",
	"stuffy",
	"stunt",
	"stupid",
	"sturdy",
	"style",
	"submit",
	"subtle",
	"subtly",
	"suburb",
	"such",
	"sudden",
	"sue",
	"suffer",
	"sugar",
	"suit",
	"suite",
	"suitor",
	"sullen",
	"sultan",
	"sum",
	"summer",
	"summit",
	"summon",
	"sun",
	"sunny",
	"sunset",
	"super",
	"superb",
	"supper",
	"supple",
	"supply",
	"sure",
	"surely",
	"surf",
	"surge",
	"survey",
	"suture",
	"swamp",
	"swan",
	"swap",
	"swarm",
	"sway",
	"swear",
	"sweat",
	"sweaty",
	"sweep",
	"sweet",
	"swell",
	"swift",
	"swim",
	"swine",
	"swing",
	"swirl",
	"switch",
	"sword",
	"swore",
	"symbol",
	"synod",
	"syntax",
	"syrup",
	"system",
	"table",
	"tablet",
	"taboo",
	"tacit",
	"tackle",
	"tact",
	"tactic",
	"tail",
	"tailor",
	"take",
	"tale",
	"talent",
	"talk",
	"tall",
	"tally",
	"tame",
	"tandem",
	"tangle",
	"tank",
	"tap",
	"tape",
	"target",
	"tariff",
	"tart",
	"task",
	"taste",
	"tasty",
	"tattoo",
	"taut",
	"tavern",
	"tax",
	"taxi",
	"tea",
	"teach",
	"teak",
	"team",
	"tear",
	"tease",
	"tech",
	"teeth",
	"tell",
	"temper",
	"temple",
	"tempo",
	"tempt",
	"ten",
	"tenant",
	"tend",
	"tender",
	"tendon",
	"tennis",
	"tenor",
	"tense",
	"tensor",
	"tent",
	"tenth",
	"tenure",
	"term",
	"terror",
	"test",
	"text",
	"than",
	"thank",
	"that",
	"the",
	"their",
	"them",
	"theme",
	"then",
	"thence",
	"theory",
	"there",
	"these",
	"thesis",
	"they",
	"thick",
	"thief",
	"thigh",
	"thin",
	"thing",
	"think",
	"third",
	"thirst",
	"thirty",
	"this",
	"thorn",
	"those",
	"though",
	"thread",
	"threat",
	"three",
	"thrill",
	"thrive",
	"throat",
	"throne",
	"throng",
	"throw",
	"thud",
	"thug",
	"thumb",
	"thus",
	"thyme",
	"tick",
	"ticket",
	"tidal",
	"tide",
	"tidy",
	"tie",
	"tier",
	"tiger",
	"tight",
	"tile",
	"till",
	"tilt",
	"timber",
	"time",
	"timid",
	"tin",
	"tiny",
	"tip",
	"tissue",
	"title",
	"toad",
	"toast",
	"today",
	"toilet",
	"token",
	"told",
	"toll",
	"tomato",
	"tomb",
	"tonal",
	"tone",
	"tongue",
	"tonic",
	"too",
	"took",
	"tool",
	"tooth",
	"top",
	"topaz",
	"topic",
	"torch",
	"torque",
	"torso",
	"tort",
	"toss",
	"total",
	"touch",
	"tough",
	"tour",
	"toward",
	"towel",
	"tower",
	"town",
	"toxic",
	"toxin",
	"trace",
	"track",
	"tract",
	"trade",
	"tragic",
	"trail",
	"train",
	"trait",
	"tram",
	"trance",
	"trap",
	"trauma",
	"travel",
	"tray",
	"tread",
	"treat",
	"treaty",
	"treble",
	"tree",
	"trek",
	"tremor",
	"trench",
	"trend",
	"trendy",
	"trial",
	"tribal",
	"tribe",
	"trick",
	"tricky",
	"tried",
	"trifle",
	"trim",
	"trio",
	"trip",
	"triple",
	"troop",
	"trophy",
	"trot",
	"trough",
	"trout",
	"truce",
	"truck",
	"true",
	"truly",
	"trunk",
	"trust",
	"truth",
	"try",
	"tsar",
	"tube",
	"tumble",
	"tuna",
	"tundra",
	"tune",
	"tung",
	"tunic",
	"tunnel",
	"turban",
	"turf",
	"turn",
	"turtle",
	"tutor",
	"tweed",
	"twelve",
	"twenty",
	"twice",
	"twin",
	"twist",
	"two",
	"tycoon",
	"tying",
	"type",
	"tyrant",
	"ugly",
	"ulcer",
	"ultra",
	"umpire",
	"unable",
	"uncle",
	"under",
	"uneasy",
	"unfair",
	"unify",
	"union",
	"unique",
	"unit",
	"unite",
	"unity",
	"unlike",
	"unrest",
	"unruly",
	"until",
	"update",
	"upheld",
	"uphill",
	"uphold",
	"upon",
	"uproar",
	"upset",
	"upshot",
	"uptake",
	"upturn",
	"upward",
	"urban",
	"urge",
	"urgent",
	"urging",
	"usable",
	"usage",
	"use",
	"useful",
	"user",
	"usual",
	"utmost",
	"utter",
	"vacant",
	"vacuum",
	"vague",
	"vain",
	"valet",
	"valid",
	"valley",
	"value",
	"valve",
	"van",
	"vanish",
	"vanity",
	"vary",
	"vase",
	"vast",
	"vat",
	"vault",
	"vector",
	"veil",
	"vein",
	"velvet",
	"vendor",
	"veneer",
	"venom",
	"vent",
	"venue",
	"verb",
	"verbal",
	"verge",
	"verify",
	"verity",
	"verse",
	"versus",
	"very",
	"vessel",
	"vest",
	"veto",
	"via",
	"viable",
	"vicar",
	"vice",
	"victim",
	"victor",
	"video",
	"view",
	"vigil",
	"vile",
	"villa",
	"vine",
	"vinyl",
	"viola",
	"violet",
	"violin",
	"viral",
	"virtue",
	"virus",
	"visa",
	"vision",
	"visit",
	"visual",
	"vital",
	"vivid",
	"vocal",
	"vodka",
	"vogue",
	"voice",
	"void",
	"volley",
	"volume",
	"vomit",
	"vote",
	"vowel",
	"voyage",
	"vulgar",
	"wade",
	"wage",
	"waist",
	"wait",
	"waiter",
	"wake",
	"walk",
	"walker",
	"wall",
	"wallet",
	"walnut",
	"wander",
	"want",
	"war",
	"warden",
	"warm",
	"warmth",
	"warn",
	"warp",
	"wary",
	"was",
	"wash",
	"wasp",
	"waste",
	"watch",
	"water",
	"watery",
	"wave",
	"way",
	"weak",
	"weaken",
	"wealth",
	"weapon",
	"wear",
	"weary",
	"wedge",
	"wee",
	"week",
	"weekly",
	"weep",
	"weight",
	"weird",
	"well",
	"were",
	"wet",
	"whale",
	"wharf",
	"what",
	"wheat",
	"wheel",
	"when",
	"whence",
	"where",
	"which",
	"whiff",
	"whig",
	"while",
	"whim",
	"whip",
	"who",
	"whole",
	"wholly",
	"whom",
	"whose",
	"why",
	"wide",
	"widely",
	"widen",
	"wider",
	"widow",
	"width",
	"wife",
	"wild",
	"wildly",
	"wilful",
	"will",
	"willow",
	"win",
	"wind",
	"window",
	"windy",
	"wine",
	"wing",
	"wink",
	"winner",
	"winter",
	"wipe",
	"wire",
	"wisdom",
	"wise",
	"wish",
	"wit",
	"witch",
	"with",
	"within",
	"witty",
	"wizard",
	"woke",
	"wolf",
	"wolves",
	"woman",
	"womb",
	"won",
	"wonder",
	"wood",
	"wooden",
	"woods",
	"woody",
	"wool",
	"word",
	"work",
	"worker",
	"world",
	"worm",
	"worry",
	"worse",
	"worst",
	"worth",
	"worthy",
	"would",
	"wound",
	"wrap",
	"wrath",
	"wreath",
	"wreck",
	"wright",
	"wrist",
	"writ",
	"write",
	"writer",
	"wrong",
	"xerox",
	"yacht",
	"yard",
	"yarn",
	"yeah",
	"year",
	"yeast",
	"yet",
	"yield",
	"yogurt",
	"yolk",
	"you",
	"young",
	"your",
	"youth",
	"zeal",
	"zebra",
	"zenith",
	"zero",
	"zigzag",
	"zinc",
	"zombie",
	"zone",
	"Africa", /* we had "Europe" */
	"Asia",
	"South", /* we had the other 3, but not this one */
	"anyone", /* some previously missed very common English words */
	"born",
	"its",
	"little",
	"man",
	"new",
	"news",
	"others",
	"yes",
	"admin", /* words common in computing */
	"avatar",
	"codec",
	"laptop",
	"online",
	"tweet",
	"aisle", /* BIP-0039 */
	"amused",
	"arena",
	"armed",
	"banner",
	"boring",
	"buddy",
	"bunker",
	"burger",
	"cannon",
	"casino",
	"churn",
	"clog",
	"clump",
	"coyote",
	"cram",
	"crouch",
	"daring",
	"embody",
	"enact",
	"enrich",
	"erase",
	"erupt",
	"ethics",
	"fiber",
	"flip",
	"gym",
	"hen",
	"hip",
	"hub",
	"inhale",
	"jar",
	"jeans",
	"kit",
	"kiwi",
	"lab",
	"lumber",
	"lyrics",
	"mango",
	"marine",
	"math",
	"mixed",
	"muffin",
	"naive",
	"net",
	"noodle",
	"nut",
	"odor",
	"panda",
	"peanut",
	"pet",
	"pluck",
	"purity",
	"ranch",
	"renew",
	"reopen",
	"rib",
	"rookie",
	"rubber",
	"rug",
	"salon",
	"scheme",
	"setup",
	"shed",
	"shove",
	"skate",
	"ski",
	"slush",
	"sniff",
	"spawn",
	"spike",
	"spy",
	"stairs",
	"subway",
	"tag",
	"tired",
	"toe",
	"topple",
	"toy",
	"trash",
	"undo",
	"unfold",
	"unlock",
	"unveil",
	"upper",
	"used",
	"wagon",
	"weasel",
	"web",
	"zoo",
	"cookie", /* more previously missed common English words */
	"cop",
	"cops",
	"dig",
	"digger",
	"dining",
	"extent",
	"gifted",
	"hunter",
	"living",
	"lots",
	"makeup",
	"nearby",
	"nod",
	"odds",
	"pan",
	"pant",
	"porch",
	"rating",
	"sales",
	"saving",
	"scared",
	"sin",
	"sinner",
	"sins",
	"terms",
	"thanks",
	"united",
	"unless",
	"viewer",
	"voter",
	"voters",
	"weigh",
	"works",
	"yell",
	"yours",
	"arms", /* gutenberg-19xx-lowercase-words-1000plus.txt top 1000 */
	"asked",
	"became",
	"been",
	"began",
	"books",
	"boys",
	"called",
	"cannot",
	"closed",
	"comes",
	"coming",
	"days",
	"died",
	"does",
	"doing",
	"drawn",
	"ears",
	"eyes",
	"faces",
	"fallen",
	"fixed",
	"girls",
	"giving",
	"goes",
	"going",
	"hands",
	"having",
	"horses",
	"hours",
	"houses",
	"knows",
	"laid",
	"leaves",
	"legs",
	"lifted",
	"liked",
	"lines",
	"lips",
	"lived",
	"lives",
	"looked",
	"looks",
	"loved",
	"makes",
	"making",
	"means",
	"men",
	"miles",
	"months",
	"moved",
	"moving",
	"needed",
	"nodded",
	"opened",
	"papers",
	"passed",
	"paused",
	"picked",
	"placed",
	"places",
	"played",
	"pounds",
	"pulled",
	"raised",
	"ran",
	"rooms",
	"sat",
	"saw",
	"saying",
	"says",
	"seemed",
	"seems",
	"seen",
	"showed",
	"smiled",
	"spent",
	"stared",
	"steps",
	"stood",
	"struck",
	"taken",
	"taking",
	"talked",
	"tears",
	"things",
	"threw",
	"times",
	"trees",
	"trying",
	"turned",
	"waited",
	"walked",
	"walls",
	"wanted",
	"ways",
	"weeks",
	"went",
	"wished",
	"women",
	"words",
	"wore",
	"worked",
	"wrote",
	"years",
	"asking", /* gutenberg-19xx-lowercase-words-1000plus.txt top 2000 */
	"begun",
	"birds",
	"bodies",
	"bones",
	"boots",
	"bowed",
	"built",
	"calls",
	"cards",
	"cared",
	"cases",
	"caused",
	"ceased",
	"chairs",
	"cheeks",
	"clouds",
	"crying",
	"damned",
	"dared",
	"dim",
	"dogs",
	"doors",
	"dreams",
	"driven",
	"ended",
	"ends",
	"events",
	"faced",
	"facts",
	"faded",
	"failed",
	"feared",
	"fields",
	"fired",
	"flying",
	"forced",
	"forgot",
	"formed",
	"fought",
	"gazed",
	"gets",
	"gives",
	"guests",
	"guns",
	"handed",
	"hated",
	"heads",
	"hearts",
	"helped",
	"hers",
	"hills",
	"hoped",
	"ideas",
	"joined",
	"jumped",
	"kissed",
	"knees",
	"ladies",
	"larger",
	"laws",
	"lies",
	"lights",
	"locked",
	"marked",
	"minds",
	"missed",
	"named",
	"names",
	"needs",
	"nerves",
	"nights",
	"noted",
	"notes",
	"ones",
	"orders",
	"parts",
	"pieces",
	"plans",
	"points",
	"powers",
	"proved",
	"pushed",
	"rang",
	"riding",
	"rising",
	"rocks",
	"rolled",
	"rushed",
	"sank",
	"saved",
	"seated",
	"seized",
	"served",
	"ships",
	"shoes",
	"shown",
	"sides",
	"sighed",
	"signs",
	"slept",
	"sought",
	"sounds",
	"spoken",
	"sprang",
	"stars",
	"stayed",
	"stones",
	"stuck",
	"swept",
	"swung",
	"takes",
	"taught",
	"thinks",
	"thrown",
	"tied",
	"turns",
	"voices",
	"wants",
	"waters",
	"whilst",
	"worn",
	"yards",
	"acted", /* gutenberg-19xx-lowercase-words-1000plus.txt top 3000 */
	"acting",
	"ages",
	"arose",
	"banks",
	"beaten",
	"beg",
	"begged",
	"begins",
	"beings",
	"blank",
	"boats",
	"bored",
	"brains",
	"brow",
	"bushes",
	"cars",
	"cent",
	"cities",
	"coldly",
	"cries",
	"cursed",
	"dashed",
	"deeper",
	"depths",
	"duties",
	"easier",
	"eating",
	"eggs",
	"facing",
	"fears",
	"feels",
	"finds",
	"fires",
	"fitted",
	"folded",
	"folks",
	"forces",
	"forms",
	"gained",
	"gasped",
	"gates",
	"gazing",
	"gods",
	"goods",
	"grimly",
	"habits",
	"halted",
	"hatred",
	"heels",
	"hid",
	"hiding",
	"hopes",
	"hoping",
	"inches",
	"jewels",
	"keeps",
	"kinds",
	"landed",
	"lands",
	"likes",
	"limbs",
	"longed",
	"losing",
	"loves",
	"loving",
	"marks",
	"mob",
	"ours",
	"packed",
	"pages",
	"parted",
	"paying",
	"posted",
	"poured",
	"rested",
	"rights",
	"risen",
	"roads",
	"roots",
	"roses",
	"roused",
	"ruined",
	"runs",
	"sailed",
	"sang",
	"sees",
	"senses",
	"shone",
	"shows",
	"signed",
	"sons",
	"sorts",
	"souls",
	"stands",
	"stated",
	"stole",
	"stolen",
	"strode",
	"tables",
	"tells",
	"tones",
	"tore",
	"torn",
	"towns",
	"tracks",
	"troops",
	"urged",
	"using",
	"views",
	"warned",
	"washed",
	"wasted",
	"waved",
	"waves",
	"wicked",
	"winds",
	"wings",
	"wishes",
	"wives",
	"acres", /* gutenberg-19xx-lowercase-words-1000plus.txt top 4000 */
	"acts",
	"adding",
	"aged",
	"amazed",
	"apt",
	"ashes",
	"awoke",
	"backed",
	"backs",
	"bade",
	"bags",
	"bars",
	"based",
	"beasts",
	"beds",
	"bells",
	"bills",
	"bits",
	"blown",
	"blows",
	"borne",
	"boxes",
	"brings",
	"brows",
	"buying",
	"carved",
	"causes",
	"choked",
	"cliffs",
	"coolly",
	"cows",
	"crops",
	"danced",
	"dealt",
	"denied",
	"dimly",
	"dishes",
	"dismay",
	"doubts",
	"drinks",
	"drops",
	"earned",
	"echoed",
	"errand",
	"falls",
	"finest",
	"flames",
	"flies",
	"fools",
	"games",
	"ghosts",
	"gifts",
	"gloves",
	"groups",
	"grows",
	"hanged",
	"hats",
	"hay",
	"headed",
	"hired",
	"holds",
	"holes",
	"homes",
	"intent",
	"issued",
	"jerked",
	"keys",
	"kicked",
	"lamps",
	"lasted",
	"laying",
	"leaped",
	"leapt",
	"liking",
	"lined",
	"loaded",
	"masses",
	"meals",
	"obeyed",
	"outfit",
	"owned",
	"pains",
	"passes",
	"pearls",
	"peered",
	"piled",
	"plains",
	"plants",
	"plays",
	"porter",
	"prayed",
	"puts",
	"races",
	"racing",
	"ragged",
	"rays",
	"rings",
	"roared",
	"robbed",
	"rows",
	"rubbed",
	"ruins",
	"rules",
	"scenes",
	"seas",
	"seats",
	"sets",
	"shaken",
	"shared",
	"sheets",
	"shops",
	"sits",
	"skirts",
	"smiles",
	"smoked",
	"songs",
	"speaks",
	"sticks",
	"stores",
	"sunk",
	"tales",
	"talks",
	"tapped",
	"theirs",
	"tossed",
	"tribes",
	"tricks",
	"unseen",
	"veins",
	"viewed",
	"visits",
	"wages",
	"walks",
	"warmly",
	"waving",
	"wheels",
	"wiped",
	"wits",
	"yelled",
	"yonder",
	"agents", /* the rest of gutenberg-19xx-lowercase-words-1000plus.txt */
	"alas",
	"argued",
	"arts",
	"asks",
	"behold",
	"boiled",
	"boldly",
	"cares",
	"chaps",
	"claims",
	"crimes",
	"crowds",
	"curled",
	"darted",
	"dazed",
	"dined",
	"dug",
	"firing",
	"flowed",
	"francs",
	"gaiety",
	"gaily",
	"git",
	"gladly",
	"glared",
	"hinted",
	"hunted",
	"ink",
	"jobs",
	"judged",
	"keenly",
	"kings",
	"knelt",
	"lacked",
	"leads",
	"morrow",
	"nails",
	"noises",
	"novels",
	"owed",
	"palms",
	"patted",
	"plates",
	"poets",
	"prey",
	"prices",
	"quoted",
	"ranks",
	"risks",
	"rivers",
	"rum",
	"sealed",
	"shaped",
	"shares",
	"shells",
	"shots",
	"spared",
	"spots",
	"starts",
	"states",
	"suited",
	"sworn",
	"tents",
	"tools",
	"traced",
	"traces",
	"trains",
	"tramp",
	"varied",
	"veiled",
	"waking",
	"wax",
	"wept",
	"wiser",
	"worlds",
	"writes",
	"affix", /* eff_short_wordlist_1.txt */
	"aging",
	"aids",
	"ajar",
	"alias",
	"aloe",
	"aloha",
	"amino",
	"aqua",
	"bagel",
	"baked",
	"balmy",
	"banjo",
	"bash",
	"bask",
	"bats",
	"blimp",
	"bloat",
	"blob",
	"blog",
	"blurt",
	"bok",
	"boned",
	"boney",
	"botch",
	"boxer",
	"bribe",
	"broil",
	"bud",
	"bunt",
	"cadet",
	"cameo",
	"canon",
	"carve",
	"cedar",
	"chili",
	"chomp",
	"chow",
	"chuck",
	"chump",
	"chute",
	"cinch",
	"clamp",
	"cleat",
	"cleft",
	"clink",
	"cod",
	"cola",
	"coma",
	"comma",
	"cot",
	"cozy",
	"cramp",
	"crank",
	"crave",
	"creme",
	"crepe",
	"crib",
	"crumb",
	"cub",
	"cupid",
	"curvy",
	"cushy",
	"dab",
	"dandy",
	"darn",
	"dart",
	"debug",
	"decaf",
	"decal",
	"decoy",
	"denim",
	"dent",
	"dill",
	"dime",
	"diner",
	"dingy",
	"ditzy",
	"dodge",
	"donut",
	"dot",
	"dowry",
	"doze",
	"drab",
	"drone",
	"droop",
	"dude",
	"duo",
	"eats",
	"ebay",
	"ebony",
	"ebook",
	"eel",
	"eject",
	"elf",
	"elk",
	"elm",
	"elope",
	"emu",
	"etch",
	"fable",
	"fang",
	"fax",
	"femur",
	"finch",
	"flaky",
	"fling",
	"flop",
	"floss",
	"foe",
	"folic",
	"fray",
	"frill",
	"frisk",
	"froth",
	"froze",
	"gag",
	"gains",
	"gecko",
	"geek",
	"gem",
	"gig",
	"gills",
	"giver",
	"gooey",
	"goofy",
	"gore",
	"grope",
	"growl",
	"grub",
	"gulp",
	"gummy",
	"gush",
	"halo",
	"heave",
	"herbs",
	"hug",
	"hula",
	"hump",
	"hunk",
	"icy",
	"igloo",
	"ion",
	"ivy",
	"jab",
	"jam",
	"jaws",
	"jiffy",
	"jog",
	"jot",
	"junky",
	"juror",
	"keg",
	"kilt",
	"kitty",
	"koala",
	"kung",
	"ladle",
	"lair",
	"lapel",
	"lash",
	"lasso",
	"lilac",
	"lily",
	"limes",
	"lint",
	"lurch",
	"lurk",
	"mace",
	"mama",
	"mardi",
	"mash",
	"mocha",
	"mold",
	"mop",
	"morse",
	"motto",
	"mousy",
	"mower",
	"mug",
	"mulch",
	"mull",
	"mumbo",
	"mural",
	"muse",
	"musky",
	"nacho",
	"nag",
	"nanny",
	"nap",
	"nerd",
	"nutty",
	"oat",
	"ooze",
	"opal",
	"opt",
	"ouch",
	"pager",
	"pants",
	"panty",
	"pasta",
	"payer",
	"pecan",
	"pep",
	"perky",
	"perm",
	"petal",
	"petri",
	"plaza",
	"plow",
	"poach",
	"pod",
	"pogo",
	"poise",
	"poker",
	"polio",
	"polka",
	"poser",
	"pout",
	"prank",
	"prong",
	"props",
	"prude",
	"pry",
	"pug",
	"puma",
	"purr",
	"quack",
	"quill",
	"rabid",
	"rake",
	"rant",
	"ream",
	"recap",
	"remix",
	"repay",
	"repel",
	"rerun",
	"reset",
	"rigor",
	"ritzy",
	"romp",
	"runny",
	"rut",
	"salsa",
	"santa",
	"savor",
	"sax",
	"scam",
	"scoff",
	"scold",
	"scoop",
	"scoot",
	"scowl",
	"scuba",
	"scuff",
	"sedan",
	"sepia",
	"shack",
	"showy",
	"shred",
	"shun",
	"shush",
	"sift",
	"silo",
	"sip",
	"skew",
	"skid",
	"skier",
	"skies",
	"skit",
	"slash",
	"slaw",
	"sled",
	"sleet",
	"slob",
	"slurp",
	"smirk",
	"smog",
	"snare",
	"snarl",
	"sneer",
	"snore",
	"snort",
	"snout",
	"snub",
	"snuff",
	"spew",
	"spied",
	"spiny",
	"spoof",
	"spool",
	"spout",
	"stank",
	"stash",
	"stays",
	"stomp",
	"stoop",
	"strut",
	"stump",
	"stung",
	"suds",
	"sulk",
	"sushi",
	"swab",
	"swipe",
	"swoop",
	"tacky",
	"taco",
	"talon",
	"tamer",
	"taper",
	"taps",
	"tarot",
	"taunt",
	"thaw",
	"theft",
	"thong",
	"throb",
	"thump",
	"tiara",
	"tint",
	"tug",
	"tulip",
	"tummy",
	"tusk",
	"tutu",
	"tux",
	"tweak",
	"twine",
	"twins",
	"twirl",
	"uncut",
	"untie",
	"usher",
	"vegan",
	"visor",
	"vixen",
	"volt",
	"wad",
	"wafer",
	"wager",
	"wand",
	"wavy",
	"whoop",
	"wick",
	"wifi",
	"wilt",
	"wimp",
	"wired",
	"wiry",
	"wispy",
	"wok",
	"woozy",
	"woven",
	"yahoo",
	"yam",
	"yelp",
	"yodel",
	"yoga",
	"yummy",
	"zesty",
	"zippy",
	"zoom",
	"abacus", /* eff_large_wordlist.txt */
	"affirm",
	"aflame",
	"afoot",
	"ahoy",
	"aliens",
	"alto",
	"alumni",
	"amends",
	"amigo",
	"amply",
	"amuck",
	"amulet",
	"amuser",
	"anemia",
	"anemic",
	"angled",
	"angler",
	"angles",
	"anime",
	"annex",
	"antics",
	"antler",
	"antsy",
	"anvil",
	"aorta",
	"apache",
	"aptly",
	"arming",
	"armory",
	"ascend",
	"ashy",
	"askew",
	"aspire",
	"atop",
	"atrium",
	"attest",
	"attire",
	"autism",
	"awning",
	"awry",
	"babble",
	"babied",
	"baboon",
	"backer",
	"badass",
	"baffle",
	"bagful",
	"bagged",
	"baggie",
	"baking",
	"banish",
	"banked",
	"banker",
	"banter",
	"barbed",
	"barman",
	"basics",
	"batboy",
	"bauble",
	"blah",
	"blazer",
	"bleach",
	"bleep",
	"bling",
	"blinks",
	"bluish",
	"blurb",
	"blurry",
	"bobbed",
	"bobble",
	"bobcat",
	"bogged",
	"boggle",
	"bonded",
	"bonsai",
	"booted",
	"bootie",
	"boozy",
	"borax",
	"botany",
	"bouncy",
	"boxcar",
	"boxing",
	"boxy",
	"breezy",
	"briar",
	"broker",
	"bronco",
	"browse",
	"brunch",
	"brunt",
	"bubbly",
	"bucked",
	"buffed",
	"buffer",
	"bulgur",
	"bungee",
	"bunion",
	"busboy",
	"busily",
	"cabana",
	"cabbie",
	"cackle",
	"cacti",
	"caddie",
	"caddy",
	"camper",
	"canned",
	"canola",
	"capped",
	"carat",
	"carded",
	"caring",
	"carton",
	"casing",
	"casket",
	"catchy",
	"catnap",
	"catnip",
	"catsup",
	"catty",
	"caucus",
	"caviar",
	"cavity",
	"chafe",
	"chaste",
	"chatty",
	"cheesy",
	"chemo",
	"cherub",
	"chevy",
	"chewer",
	"chewy",
	"chimp",
	"chirpy",
	"chive",
	"choosy",
	"chubby",
	"chug",
	"chummy",
	"citric",
	"citrus",
	"clamor",
	"clang",
	"clench",
	"clique",
	"clover",
	"clunky",
	"cobweb",
	"coerce",
	"collie",
	"comfy",
	"conch",
	"copied",
	"copier",
	"coping",
	"cornea",
	"corned",
	"corny",
	"corral",
	"corset",
	"cozily",
	"crayon",
	"crazed",
	"crease",
	"creole",
	"crier",
	"crimp",
	"cringe",
	"crispy",
	"croak",
	"crock",
	"croon",
	"crummy",
	"cuddle",
	"cuddly",
	"cupped",
	"curdle",
	"curing",
	"curler",
	"curly",
	"curtly",
	"curtsy",
	"cusp",
	"cussed",
	"cymbal",
	"dainty",
	"dander",
	"dangle",
	"dares",
	"dating",
	"daybed",
	"deacon",
	"debunk",
	"deceit",
	"decode",
	"deduct",
	"deem",
	"deepen",
	"deface",
	"defame",
	"defile",
	"defog",
	"deftly",
	"defuse",
	"deluge",
	"deluxe",
	"demote",
	"deport",
	"depose",
	"derail",
	"deuce",
	"diaper",
	"dicing",
	"dilute",
	"dimmed",
	"dimmer",
	"dimple",
	"dingo",
	"dipped",
	"dipper",
	"disarm",
	"disown",
	"ditto",
	"diving",
	"doable",
	"dodgy",
	"doily",
	"dollop",
	"doodle",
	"doozy",
	"dork",
	"dosage",
	"dotted",
	"douche",
	"dreamt",
	"dreamy",
	"drench",
	"drier",
	"drippy",
	"drool",
	"drudge",
	"dubbed",
	"ducky",
	"duffel",
	"dugout",
	"duh",
	"duller",
	"dupe",
	"duplex",
	"duvet",
	"dweeb",
	"earful",
	"earthy",
	"earwig",
	"easing",
	"eatery",
	"ecard",
	"eclair",
	"edging",
	"edgy",
	"egging",
	"eggnog",
	"elated",
	"elixir",
	"ember",
	"emboss",
	"emcee",
	"emote",
	"encode",
	"encore",
	"ending",
	"engulf",
	"enrage",
	"entity",
	"entomb",
	"entrap",
	"entree",
	"erased",
	"eraser",
	"eskimo",
	"ether",
	"exes",
	"exhale",
	"exhume",
	"expel",
	"expend",
	"extras",
	"fading",
	"faucet",
	"fedora",
	"feisty",
	"feline",
	"fender",
	"ferret",
	"ferris",
	"fervor",
	"fester",
	"filing",
	"finer",
	"flail",
	"flashy",
	"flatly",
	"flier",
	"flinch",
	"fondue",
	"footer",
	"frayed",
	"frays",
	"frolic",
	"frying",
	"gab",
	"gaffe",
	"galore",
	"gaming",
	"gander",
	"gangly",
	"gargle",
	"garnet",
	"garter",
	"gating",
	"gauze",
	"gawk",
	"geiger",
	"gents",
	"gerbil",
	"getup",
	"giblet",
	"giddy",
	"giggly",
	"gilled",
	"girdle",
	"gizmo",
	"glider",
	"glitch",
	"glitzy",
	"gluten",
	"gnarly",
	"gnat",
	"gonad",
	"google",
	"goon",
	"gopher",
	"gorged",
	"gotten",
	"gout",
	"graded",
	"grader",
	"granny",
	"graves",
	"grime",
	"grimy",
	"grinch",
	"groggy",
	"groovy",
	"grout",
	"grower",
	"grunge",
	"gurgle",
	"gusto",
	"gusty",
	"guts",
	"gutter",
	"hacked",
	"hacker",
	"haiku",
	"halved",
	"halves",
	"hamper",
	"hangup",
	"hankie",
	"hanky",
	"hardy",
	"hatbox",
	"hazily",
	"hazing",
	"header",
	"helper",
	"henna",
	"herbal",
	"hermit",
	"hertz",
	"hubcap",
	"huddle",
	"huff",
	"hulk",
	"humbly",
	"hummus",
	"humped",
	"humvee",
	"hurled",
	"hurler",
	"hurray",
	"husked",
	"icky",
	"idiocy",
	"iguana",
	"impale",
	"impart",
	"impish",
	"impure",
	"iodine",
	"iodize",
	"ipad",
	"iphone",
	"ipod",
	"irate",
	"irk",
	"itunes",
	"jackal",
	"jailer",
	"jaunt",
	"jawed",
	"jester",
	"jigsaw",
	"jimmy",
	"jingle",
	"jinx",
	"jogger",
	"jovial",
	"judo",
	"juggle",
	"junkie",
	"jurist",
	"justly",
	"kabob",
	"karma",
	"kebab",
	"kelp",
	"kennel",
	"kiln",
	"kimono",
	"kindle",
	"kisser",
	"knoll",
	"kooky",
	"kosher",
	"kudos",
	"lagged",
	"lanky",
	"lapdog",
	"lapped",
	"lard",
	"lark",
	"lather",
	"laurel",
	"lazily",
	"legged",
	"lego",
	"legume",
	"levers",
	"lifter",
	"lilly",
	"lingo",
	"lining",
	"linked",
	"lisp",
	"litmus",
	"litter",
	"lugged",
	"lushly",
	"luster",
	"lusty",
	"macaw",
	"maggot",
	"maimed",
	"manger",
	"mangle",
	"mangy",
	"manila",
	"manly",
	"manned",
	"mantis",
	"mantra",
	"marlin",
	"maroon",
	"marrow",
	"marshy",
	"mascot",
	"mashed",
	"mating",
	"matron",
	"matted",
	"mauve",
	"mayday",
	"moaner",
	"mocker",
	"mockup",
	"mooing",
	"mooned",
	"mossy",
	"mowing",
	"mulled",
	"mumble",
	"mumps",
	"muppet",
	"mushy",
	"musket",
	"muster",
	"musty",
	"mutate",
	"mutt",
	"naming",
	"napped",
	"nappy",
	"nebula",
	"nectar",
	"nervy",
	"neuron",
	"neuter",
	"nibble",
	"nifty",
	"nimbly",
	"ninja",
	"nuclei",
	"nugget",
	"numbly",
	"nutmeg",
	"nuzzle",
	"oaf",
	"oblong",
	"obtuse",
	"ocelot",
	"octane",
	"ogle",
	"oink",
	"onyx",
	"oops",
	"oozy",
	"outage",
	"outbid",
	"outing",
	"outlet",
	"outwit",
	"ovary",
	"paced",
	"pacify",
	"padded",
	"paging",
	"paltry",
	"pang",
	"pantry",
	"papaya",
	"parka",
	"parlor",
	"parole",
	"pasted",
	"pasty",
	"patchy",
	"pauper",
	"paver",
	"paving",
	"pawing",
	"payday",
	"payee",
	"pebble",
	"pebbly",
	"pectin",
	"pellet",
	"pelt",
	"penpal",
	"pesky",
	"peso",
	"pester",
	"petted",
	"phobia",
	"phoney",
	"phony",
	"plated",
	"pleat",
	"plod",
	"plop",
	"pointy",
	"poking",
	"poncho",
	"poplar",
	"popper",
	"porous",
	"portly",
	"posing",
	"possum",
	"poster",
	"pounce",
	"powwow",
	"pox",
	"prance",
	"precut",
	"prelaw",
	"prepay",
	"preppy",
	"preset",
	"prewar",
	"pried",
	"primer",
	"primp",
	"prissy",
	"pronto",
	"proofs",
	"prozac",
	"pucker",
	"pueblo",
	"pumice",
	"pummel",
	"purist",
	"pusher",
	"pushup",
	"python",
	"quail",
	"qualm",
	"quench",
	"racoon",
	"radial",
	"raging",
	"raider",
	"raisin",
	"raking",
	"ramble",
	"ramrod",
	"ranged",
	"ranger",
	"ranked",
	"rants",
	"rascal",
	"ravage",
	"ravine",
	"raving",
	"rebate",
	"reboot",
	"reborn",
	"rebuff",
	"recant",
	"recast",
	"recede",
	"recite",
	"recoil",
	"recopy",
	"refill",
	"reflex",
	"reflux",
	"refold",
	"refund",
	"refute",
	"regain",
	"reggae",
	"rehab",
	"reheat",
	"rehire",
	"rejoin",
	"relive",
	"reload",
	"relock",
	"remake",
	"remold",
	"rename",
	"rented",
	"renter",
	"repave",
	"replay",
	"repose",
	"repost",
	"reps",
	"resale",
	"reseal",
	"resend",
	"resize",
	"retake",
	"retold",
	"retool",
	"retry",
	"retype",
	"reuse",
	"reverb",
	"revert",
	"revoke",
	"rewash",
	"rewind",
	"rewire",
	"reword",
	"rework",
	"rewrap",
	"riches",
	"richly",
	"ridden",
	"rimmed",
	"rind",
	"rink",
	"roamer",
	"rocker",
	"roping",
	"roster",
	"roving",
	"ruckus",
	"rumor",
	"runner",
	"runt",
	"ruse",
	"sadden",
	"saggy",
	"salami",
	"sandal",
	"sanded",
	"sappy",
	"sassy",
	"saucy",
	"savior",
	"scabby",
	"scion",
	"scone",
	"scorch",
	"scored",
	"scorer",
	"scouts",
	"scribe",
	"scurvy",
	"sedate",
	"seduce",
	"septic",
	"septum",
	"sesame",
	"shaded",
	"shale",
	"shank",
	"shanty",
	"sheath",
	"shelve",
	"shifty",
	"shimmy",
	"shorts",
	"shorty",
	"shriek",
	"shrubs",
	"shrunk",
	"siding",
	"sierra",
	"siesta",
	"silica",
	"silt",
	"simile",
	"sitcom",
	"sitter",
	"sizing",
	"sizzle",
	"skater",
	"skewed",
	"skewer",
	"skied",
	"skiing",
	"skype",
	"slacks",
	"sliced",
	"slicer",
	"slider",
	"slinky",
	"sliver",
	"sloped",
	"sludge",
	"sly",
	"smite",
	"smith",
	"smock",
	"smudge",
	"smudgy",
	"smugly",
	"snazzy",
	"sneeze",
	"snide",
	"snitch",
	"snooze",
	"snugly",
	"specks",
	"sphinx",
	"spiffy",
	"spilt",
	"spleen",
	"splice",
	"spoils",
	"spongy",
	"spooky",
	"spore",
	"sports",
	"sporty",
	"spotty",
	"sprain",
	"sprawl",
	"sprig",
	"sprite",
	"sprout",
	"spruce",
	"sprung",
	"spry",
	"spud",
	"squall",
	"squeak",
	"squint",
	"squire",
	"starry",
	"steed",
	"stilt",
	"stingy",
	"stinky",
	"stoic",
	"stoke",
	"stooge",
	"strep",
	"strewn",
	"strobe",
	"strum",
	"strung",
	"stucco",
	"stupor",
	"stylus",
	"suave",
	"sublet",
	"subpar",
	"sudoku",
	"suffix",
	"suing",
	"sulfur",
	"sultry",
	"surfer",
	"swerve",
	"swivel",
	"swoosh",
	"tabby",
	"talcum",
	"tamale",
	"tamper",
	"tanned",
	"tarmac",
	"tartar",
	"tartly",
	"tassel",
	"tattle",
	"thinly",
	"thrash",
	"thrift",
	"tibia",
	"tidbit",
	"tiling",
	"timing",
	"tingle",
	"tingly",
	"tinker",
	"tinsel",
	"tipoff",
	"tipped",
	"tipper",
	"tiptop",
	"tiring",
	"traps",
	"triage",
	"tripod",
	"trowel",
	"trunks",
	"tubby",
	"turret",
	"twerp",
	"twig",
	"twisty",
	"twitch",
	"tyke",
	"udder",
	"unbend",
	"unbent",
	"unclad",
	"unclip",
	"unclog",
	"uncork",
	"undead",
	"undone",
	"unease",
	"uneven",
	"unglue",
	"unholy",
	"unhook",
	"unison",
	"unkind",
	"unlit",
	"unmade",
	"unpack",
	"unpaid",
	"unplug",
	"unread",
	"unreal",
	"unripe",
	"unroll",
	"unsafe",
	"unsaid",
	"unsent",
	"unsnap",
	"unsold",
	"unsure",
	"untidy",
	"untold",
	"untrue",
	"unused",
	"unwary",
	"unwed",
	"unwell",
	"unwind",
	"unworn",
	"unzip",
	"upbeat",
	"upload",
	"uproot",
	"upside",
	"uptown",
	"upwind",
	"urchin",
	"utopia",
	"vacate",
	"valium",
	"vastly",
	"veal",
	"veggie",
	"velcro",
	"vibes",
	"viper",
	"vista",
	"voting",
	"vowed",
	"waffle",
	"waged",
	"waggle",
	"walrus",
	"waltz",
	"wasabi",
	"washer",
	"whacky",
	"wham",
	"whinny",
	"whiny",
	"whoops",
	"widget",
	"wilder",
	"willed",
	"wince",
	"wiring",
	"wobble",
	"wobbly",
	"woof",
	"wooing",
	"wow",
	"wrench",
	"xbox",
	"yearly",
	"yen",
	"yin",
	"yippee",
	"zap",
	"zen",
	"zips",
	"zit",
	"zodiac",
	"zoning",
	"abyss", /* eff_short_wordlist_2_0.txt */
	"algae",
	"amoeba",
	"anklet",
	"apnea",
	"azalea",
	"boiler",
	"cashew",
	"dibs",
	"dozed",
	"dryer",
	"edged",
	"eulogy",
	"fillet",
	"foggy",
	"geyser",
	"iconic",
	"jetski",
	"kayak",
	"kiosk",
	"llama",
	"luau",
	"ocular",
	"oomph",
	"owlish",
	"peony",
	"pewter",
	"pulley",
	"scythe",
	"shovel",
	"skulk",
	"sloth",
	"tirade",
	"trucks",
	"tryout",
	"tuxedo",
	"untied",
	"upkeep",
	"wakeup",
	"yuppie",
	"zealot",
	"bush", /* these two were merely words, now may be taken as referring to specific people */
	"trump",
	"church", /* religious references (more of these are among the capitalized words below) */
	"devil",
	"devils",
	"easter",
	"gospel",
	"satan",
	"black", /* races, skin colors, and ethnicities */
	"blacks",
	"brown",
	"white",
	"yellow",
	"Afghan", /* assorted capitalized words undesirable in passphrases, including: */
	"Allah", /* religious references */
	"Anglo", /* ethnicities, nationalities (but country names stay), other categories of people */
	"Arab",
	"Asian",
	"Bach", /* specific people */
	"Basque",
	"Bible",
	"Briton",
	"Buddha",
	"Caesar",
	"Celtic",
	"Christ",
	"Danish",
	"Darwin",
	"Dutch",
	"Exodus",
	"French",
	"Gandhi",
	"Gaul",
	"German",
	"God",
	"Greek",
	"Hebrew",
	"Hindu",
	"Hitler",
	"Indian",
	"Irish",
	"Islam",
	"Jesus",
	"Jewish",
	"Judas",
	"Koran",
	"Madame", /* has an inappropriate meaning */
	"Moses",
	"Moslem",
	"Mrs", /* abbreviation */
	"Muslim",
	"Nazi",
	"Nobel",
	"Pascal",
	"Polish",
	"Ritz", /* brands (the EFF lists also include some, but might not be reached) */
	"Saudi",
	"Saxon",
	"Scot",
	"Sony", /* "Amazon" stayed for its original meaning */
	"Soviet",
	"Stalin",
	"Swiss",
	"Turk",
	"abort", /* generally politically incorrect */
	"master",
	"slave",
	"slaves",
	"booze", /* some references to drugs and alcohol (but specific drink names stay above) */
	"crack",
	"heroin",
	"joint",
	"opium",
	"pot",
	"weed",
	"kill", /* violence */
	"killed",
	"killer",
	"murder",
	"rape",
	"arouse", /* obscene, intimate anatomy, sexually explicit or suggestive */
	"ass",
	"babe",
	"bang",
	"bitch",
	"blew",
	"blow",
	"breast",
	"butt",
	"carnal",
	"cervix",
	"chick",
	"climax",
	"cock",
	"daddy",
	"erect",
	"erotic",
	"escort",
	"facial",
	"flirt",
	"gay",
	"gigolo",
	"horny",
	"incest",
	"lick",
	"lover",
	"lovers",
	"naked",
	"nude",
	"oral",
	"orgasm",
	"penis",
	"piss",
	"pussy",
	"queer",
	"rectal",
	"sadism",
	"screw",
	"sex",
	"sexual",
	"sexy",
	"shit",
	"sperm",
	"squirt",
	"strip",
	"suck",
	"thrust", /* Ubuntu bug 1407629 claims "Probe!thrust6scorn" is inappropriate */
	"urine",
	"uterus", /* "womb" is on EFF lists, so assumed OK - more figurative than anatomical */
	"vagina",
	"virgin",
	"whore",
	"advice", /* too similar */
	"advise",
	"armor", /* multiple spellings */
	"armour",
	"burned",
	"burnt",
	"center",
	"centre",
	"cheque", /* or "check", which is preserved above for different meaning */
	"color",
	"colour",
	"email", /* or "e-mail" */
	"enroll", /* or "enrol" */
	"favor",
	"favour",
	"flavor", /* or "flavour" */
	"gipsy",
	"gray",
	"grey",
	"gypsy",
	"harbor", /* or "harbour" */
	"hippie",
	"hippy",
	"honor",
	"honour",
	"humor",
	"humour",
	"labor",
	"labour",
	"leaned",
	"leant",
	"learnt", /* or "learned" */
	"mom",
	"mum",
	"tire",
	"tyre",
	"vapor",
	"vapour",
	"whisky", /* or "whiskey" */
	"yoyo", /* or "yo-yo" */
	"etc", /* Latin, not English */
#if 0 /* obsolete, dialectal, and non-words from gutenberg-19xx-lowercase-words-1000plus.txt */
	"des",
	"ere",
	"fer",
	"fro",
	"hath",
	"thee",
	"thet",
	"thou",
	"thy",
	"unto",
	"von",
	"wid",
	"yer",
	"html", /* obvious noise from how gutenberg-19xx-lowercase-words-1000plus.txt was created */
	"http",
	"txt",
#endif
	"" /* end of list marker */
};
